Official Stripe Bindings for Python
===================================

A Python library for Stripe's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install stripe

Or:

    $ easy_install stripe


Setting up a Stripe Account
---------------------------

Sign up for Stripe at https://dashboard.stripe.com/register.

Using the Stripe API
--------------------

Documentation for the python bindings can be found alongside Stripe's other bindings here:

- https://stripe.com/docs
- https://stripe.com/docs/api/?lang=python

In the standard documentation (the first link), most of the reference pages will have examples in Stripe's official bindings (including Python). Just click on the Python tab to get the relevant documentation.

In the full API reference for python (the second link), the right half of the page will provide example requests and responses for various API calls.
